from setuptools import setup, find_packages
  
setup(
    name="MDS_big_advantrue", 
    version="0.1",
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description="A small example package",
    url='https://github.com/chen-yuhong/DATA533-step3.git',
    author="Henry(Yiheng) Luo; Yuhong Chen",    
    author_email="henryluo@student.ubc.ca"
)
